import { __decorate } from 'tslib';
import { EventEmitter, ɵɵdefineInjectable, Injectable, NgModule } from '@angular/core';

var NgAudioRecorderService_1;
let NgAudioRecorderService = NgAudioRecorderService_1 = class NgAudioRecorderService {
    constructor() {
        this.chunks = [];
        this.recorderEnded = new EventEmitter();
        this.appendToChunks = (event) => {
            this.chunks.push(event.data);
        };
        this.recordingStopped = (event) => {
            const blob = new Blob(this.chunks, { type: 'audio/webm' });
            this.chunks = [];
            this.recorderEnded.emit(blob);
            this.clear();
        };
    }
    static getUserConsent() {
        return navigator.mediaDevices.getUserMedia({ audio: true });
    }
    startRecording() {
        NgAudioRecorderService_1.getUserConsent().then((mediaStream) => {
            this.recorder = new MediaRecorder(mediaStream);
            this.addListeners();
            this.recorder.start();
        });
    }
    stopRecording(outputFormat) {
        return new Promise((resolve, reject) => {
            this.recorderEnded.subscribe((blob) => {
                if (outputFormat === OutputFormat.BLOB) {
                    resolve(blob);
                }
                if (outputFormat === OutputFormat.BLOB_URL) {
                    const audioURL = URL.createObjectURL(blob);
                    resolve(audioURL);
                }
            });
            this.recorder.stop();
        });
    }
    addListeners() {
        this.recorder.ondataavailable = this.appendToChunks;
        this.recorder.onstop = this.recordingStopped;
    }
    clear() {
        this.recorder = null;
        this.chunks = [];
    }
};
NgAudioRecorderService.ɵprov = ɵɵdefineInjectable({ factory: function NgAudioRecorderService_Factory() { return new NgAudioRecorderService(); }, token: NgAudioRecorderService, providedIn: "root" });
NgAudioRecorderService = NgAudioRecorderService_1 = __decorate([
    Injectable({
        providedIn: 'root'
    })
], NgAudioRecorderService);
var OutputFormat;
(function (OutputFormat) {
    OutputFormat[OutputFormat["BLOB_URL"] = 0] = "BLOB_URL";
    OutputFormat[OutputFormat["BLOB"] = 1] = "BLOB";
})(OutputFormat || (OutputFormat = {}));

let NgAudioRecorderModule = class NgAudioRecorderModule {
};
NgAudioRecorderModule = __decorate([
    NgModule({
        declarations: [],
        imports: [],
        exports: [],
        providers: [
            NgAudioRecorderService
        ]
    })
], NgAudioRecorderModule);

/*
 * Public API Surface of ng-audio-recorder
 */

/**
 * Generated bundle index. Do not edit.
 */

export { NgAudioRecorderModule, NgAudioRecorderService, OutputFormat };
//# sourceMappingURL=ng-audio-recorder.js.map
